==> estateplat-common-1.2.3-20190319.105954-232-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxxCxjg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-5-17
 * @description 不动产收费信息查询结果表
 */
@Table(name = "BDC_SFXXCXJG")
public class BdcSfxxCxjg {
    @Id
    private String jgid; //结果id
    private String slbh; //受理编号
    private String lcmc;//流程名称
    private String jdmc;//节点名称
    private String zl;//坐落
    private String qlr;//权利人
    private String ywr;//义务人
    private Double ssje;//实收金额
    private String dyzt;//打印状态
    private Date dysj;//打印时间
    private String jbr;//打印人
    private String jlid;//查询记录ID

    public String getJgid() {
        return jgid;
    }

    public void setJgid(String jgid) {
        this.jgid = jgid;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public String getLcmc() {
        return lcmc;
    }

    public void setLcmc(String lcmc) {
        this.lcmc = lcmc;
    }

    public String getJdmc() {
        return jdmc;
    }

    public void setJdmc(String jdmc) {
        this.jdmc = jdmc;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public Double getSsje() {
        return ssje;
    }

    public void setSsje(Double ssje) {
        this.ssje = ssje;
    }

    public String getDyzt() {
        return dyzt;
    }

    public void setDyzt(String dyzt) {
        this.dyzt = dyzt;
    }

    public Date getDysj() {
        return dysj;
    }

    public void setDysj(Date dysj) {
        this.dysj = dysj;
    }

    public String getJbr() {
        return jbr;
    }

    public void setJbr(String jbr) {
        this.jbr = jbr;
    }

    public String getJlid() {
        return jlid;
    }

    public void setJlid(String jlid) {
        this.jlid = jlid;
    }
}

==> estateplat-common-1.2.4-20210819.025823-846-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxxCxjg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-5-17
 * @description 不动产收费信息查询结果表
 */
@Table(name = "BDC_SFXXCXJG")
public class BdcSfxxCxjg {
    @Id
    private String jgid; //结果id
    private String slbh; //受理编号
    private String lcmc;//流程名称
    private String jdmc;//节点名称
    private String zl;//坐落
    private String qlr;//权利人
    private String ywr;//义务人
    private Double ssje;//实收金额
    private String dyzt;//打印状态
    private Date dysj;//打印时间
    private String jbr;//打印人
    private String jlid;//查询记录ID
    private String sfykqjf;//是否一卡清缴费
    private Double sfje;//税费金额

    public String getJgid() {
        return jgid;
    }

    public void setJgid(String jgid) {
        this.jgid = jgid;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public String getLcmc() {
        return lcmc;
    }

    public void setLcmc(String lcmc) {
        this.lcmc = lcmc;
    }

    public String getJdmc() {
        return jdmc;
    }

    public void setJdmc(String jdmc) {
        this.jdmc = jdmc;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public Double getSsje() {
        return ssje;
    }

    public void setSsje(Double ssje) {
        this.ssje = ssje;
    }

    public String getDyzt() {
        return dyzt;
    }

    public void setDyzt(String dyzt) {
        this.dyzt = dyzt;
    }

    public Date getDysj() {
        return dysj;
    }

    public void setDysj(Date dysj) {
        this.dysj = dysj;
    }

    public String getJbr() {
        return jbr;
    }

    public void setJbr(String jbr) {
        this.jbr = jbr;
    }

    public String getJlid() {
        return jlid;
    }

    public void setJlid(String jlid) {
        this.jlid = jlid;
    }

    public String getSfykqjf() {
        return sfykqjf;
    }

    public void setSfykqjf(String sfykqjf) {
        this.sfykqjf = sfykqjf;
    }

    public Double getSfje() {
        return sfje;
    }

    public void setSfje(Double sfje) {
        this.sfje = sfje;
    }
}
